
#ifndef __RDBTRACEBLOCKLIST_HH
#define __RDBTRACEBLOCKLIST_HH

#include <vector>
#include <string>

#include "BPNGDefines.h"

/// Implementation class for a wrapper of IRdbTraceBlock using STL classes
/**
 To achieve a compiler independend interface for the blue PiraT 2 client library
 only pointer to complex objects are returned from some functions. The IRdbTraceBlock
 class can be wrapped by this class RdbTraceBlock to have access to its members in
 the usual way. You only have to pass a IRdbTraceBlock pointer to the constructor.

\sa IRdbEvent, RdbEventList
*/
struct RdbTraceBlock
{
    RdbTraceBlock(IRdbTraceBlock* rdbBlock)
    {
        m_uniqueID = rdbBlock->getUniqueId();
        m_loggerModuleName = rdbBlock->getLoggerModuleName();
        m_filePath = rdbBlock->getFilePath();
        m_fileName = rdbBlock->getFileName();;
        m_dataFileSize = rdbBlock->getDataFileSize();
        m_dataSize = rdbBlock->getDataSize();
        m_dataStartTimeUTC = rdbBlock->getStartTimeStamp();
        m_dataEndTimeUTC = rdbBlock->getEndTimeStamp();
        m_blockNr = rdbBlock->getBlockNumber();
        m_timeZone = rdbBlock->getTimeZone();
        m_cfgBackupFile = rdbBlock->getCfgBackupFile();
        m_CAN_CANextData = rdbBlock->getDataColumnValue("CAN_CANextData");
        m_MOST25Data = rdbBlock->getDataColumnValue("MOST25Data");
        m_serialData = rdbBlock->getDataColumnValue("SerialData");
        m_ethernetData = rdbBlock->getDataColumnValue("EthernetData");
        m_flexRayData = rdbBlock->getDataColumnValue("FlexRayData");
        m_LINData = rdbBlock->getDataColumnValue("LINData");
        m_apixData = rdbBlock->getDataColumnValue("ApixData");
        m_MOST150Data = rdbBlock->getDataColumnValue("MOST150Data");
        m_cameraData = rdbBlock->getDataColumnValue("CameraData");
        m_analogData = rdbBlock->getDataColumnValue("AnalogData");
        m_gpioData = rdbBlock->getDataColumnValue("GpioData");
        m_audioData = rdbBlock->getDataColumnValue("AudioData");
        m_CCPXCPData = rdbBlock->getDataColumnValue("CCPXCPData");
        m_diagData = rdbBlock->getDataColumnValue("DiagData");
        m_GPSData = rdbBlock->getDataColumnValue("GPSData");
        m_ECLData = rdbBlock->getDataColumnValue("ECLData");
        m_CLASSData = rdbBlock->getDataColumnValue("CLASSData");
        m_complexFilterData = rdbBlock->getDataColumnValue("ComplexFilterData");
        m_TTYData = rdbBlock->getDataColumnValue("TTYData");
        m_comment = rdbBlock->getComment();
    }

    uint64_t m_uniqueID;
    std::string m_loggerModuleName;
    std::string m_filePath;
    std::string m_fileName;
    uint64_t m_dataFileSize;
    uint64_t m_dataSize;
    uint64_t m_dataStartTimeUTC;
    uint64_t m_dataEndTimeUTC;
    uint64_t m_blockNr;
    std::string m_timeZone;
    std::string m_cfgBackupFile;
    std::string m_CAN_CANextData;
    std::string m_MOST25Data;
    std::string m_serialData;
    std::string m_ethernetData;
    std::string m_flexRayData;
    std::string m_LINData;
    std::string m_apixData;
    std::string m_MOST150Data;
    std::string m_cameraData;
    std::string m_analogData;
    std::string m_gpioData;
    std::string m_audioData;
    std::string m_CCPXCPData;
    std::string m_diagData;
    std::string m_GPSData;
    std::string m_ECLData;
    std::string m_CLASSData;
    std::string m_complexFilterData;
    std::string m_TTYData;
    std::string m_comment;
};

/// Implementation class for a wrapper of IRdbTraceBlockList using STL classes
/**
 To achieve a compiler independend interface for the blue PiraT 2 client library
 only pointer to complex objects are returned from some functions.
 The class IRdbTraceBlockList is nothing else than a vector of IRdbTraceBlock objects.
 Pass a pointer to IRdbTraceBlockList to the constructor of this wrapper class RdbTraceBlockList
 and you get a STL vector of RdbTraceBlock objects which by itself is a wrapper to IRdbTraceBlock

 \sa RdbTraceBlock, IRdbTraceBlockList, IRdbTraceBlock
*/
class RdbTraceBlockList : public std::vector<RdbTraceBlock>
{
public:
    RdbTraceBlockList(IRdbTraceBlockList* list)
    {
        int size = list->getSize();
        this->reserve(size);
        for (int i = 0; i < size; ++i)
        {
            this->push_back(RdbTraceBlock(list->getTraceBlock(i)));
        }
    }
};

#endif // __RDBTRACEBLOCKLIST_HH